@@ -579,6 +579,14 @@ class TestPolicy(unittest.TestCase):
             if hasattr(policy, "sysConfig"):
                 self.assertTrue("default" not in policy.sysConfig.get_switch_names())
 
+    def test_policies___sysconfig_default_is_not_a_switch_after_sysConfig_modification(self):
+        # 2021/09/28 - was a bug with sysConfig containing the switch `default="sanitise"` after being modified
+        for policy_subclass in glasswall.content_management.policies.policy.Policy.__subclasses__():
+            policy = getattr(glasswall.content_management.policies, policy_subclass.__name__)(config={"sysConfig": {"interchange_type": "sisl"}})
+
+            if hasattr(policy, "sysConfig"):
+                self.assertTrue("default" not in policy.sysConfig.get_switch_names())
+
     def test_archive_manager_custom_policy___attributes_and_switches_customisable(self):
         policy = glasswall.content_management.policies.ArchiveManager(
             default="sanitise",
